@@ -9,9 +9,20 @@ or GPL2.txt for full copies of the license.
 #ifndef __FILLERS_H
 #define __FILLERS_H
 
+/*
+ * https://chromium.googlesource.com/chromiumos/third_party/kernel/+/096925a44076ba5c52faa84d255a847130ff341e%5E%21/#F2
+ * This commit diverged the ChromiumOS kernel from stock in the area of audit
+ * information, which this probe accesses.
+ *
+ * If running on a patched version of COS, enable this #define to get the
+ * probe to build.
+ */
+//#define COS_73_WORKAROUND
+
 #include "../ppm_flag_helpers.h"
 
 #include <linux/tty.h>
+#include <linux/audit.h>
 
 #define FILLER_RAW(x)							\
 static __always_inline int __bpf_##x(struct filler_data *data);		\
@@ -1885,6 +1896,8 @@ FILLER(proc_startupdate_3, true)
 		kgid_t egid;
 		pid_t vtid;
 		pid_t vpid;
+		struct pid_namespace *pidns = bpf_task_active_pid_ns(task);
+		int pidns_level = _READ(pidns->level);
 
 		/*
 		 * flags
@@ -1896,6 +1909,18 @@ FILLER(proc_startupdate_3, true)
 
 		flags = clone_flags_to_scap(flags);
 
+		if(pidns_level != 0) {
+			flags |= PPM_CL_CHILD_IN_PIDNS;
+		} else {
+			struct nsproxy *nsproxy = _READ(task->nsproxy);
+			if(nsproxy) {
+				struct pid_namespace *pid_ns_for_children = _READ(nsproxy->pid_ns_for_children);
+				if(pid_ns_for_children != pidns) {
+					flags |= PPM_CL_CHILD_IN_PIDNS;
+				}
+			}
+		}
+
 		res = bpf_val_to_ring_type(data, flags, PT_FLAGS32);
 		if (res != PPM_SUCCESS)
 			return res;
@@ -2014,7 +2039,19 @@ FILLER(proc_startupdate_3, true)
 		 * loginuid
 		 */
 		/* TODO: implement user namespace support */
+#ifdef COS_73_WORKAROUND
+		{
+			struct audit_task_info* audit = _READ(task->audit);
+			if (audit) {
+				loginuid = _READ(audit->loginuid);
+			} else {
+				loginuid = INVALID_UID;
+			}
+		}
+#else
 		loginuid = _READ(task->loginuid);
+#endif
+
 		res = bpf_val_to_ring_type(data, loginuid.val, PT_INT32);
 		if (res != PPM_SUCCESS)
 			return res;
