@@ -404,7 +404,7 @@ inline u32 compute_snaplen(struct event_filler_arguments *args, char *buf, u32 l
 							) {
 						sockfd_put(sock);
 						return 2000;
-					} else if (dport == PPM_PORT_STATSD) {
+					} else if (dport == args->consumer->statsd_port) {
 						sockfd_put(sock);
 						return 2000;
 					} else {
@@ -1112,7 +1112,7 @@ int32_t parse_readv_writev_bufs(struct event_filler_arguments *args, const struc
 {
 	int32_t res;
 	const struct iovec *iov;
-	u32 copylen;
+	u64 copylen;
 	u32 j;
 	u64 size = 0;
 	unsigned long bufsize;
@@ -1125,6 +1125,9 @@ int32_t parse_readv_writev_bufs(struct event_filler_arguments *args, const struc
 
 	copylen = iovcnt * sizeof(struct iovec);
 
+	if (unlikely(iovcnt >= 0xffffffff))
+		return PPM_FAILURE_BUFFER_FULL;
+
 	if (unlikely(copylen >= STR_STORAGE_SIZE))
 		return PPM_FAILURE_BUFFER_FULL;
 
@@ -1245,7 +1248,7 @@ int32_t compat_parse_readv_writev_bufs(struct event_filler_arguments *args, cons
 {
 	int32_t res;
 	const struct compat_iovec *iov;
-	u32 copylen;
+	u64 copylen;
 	u32 j;
 	u64 size = 0;
 	unsigned long bufsize;
@@ -1258,6 +1261,9 @@ int32_t compat_parse_readv_writev_bufs(struct event_filler_arguments *args, cons
 
 	copylen = iovcnt * sizeof(struct compat_iovec);
 
+	if (unlikely(iovcnt >= 0xffffffff))
+		return PPM_FAILURE_BUFFER_FULL;
+
 	if (unlikely(copylen >= STR_STORAGE_SIZE))
 		return PPM_FAILURE_BUFFER_FULL;
 
